#ifndef MAIN_H
#define MAIN_H

// namespace rtsNS {
  int mainx(int *k2f, int *f2k); //int argc, char *argv[]
// }

#endif
